microsoft_kiota_serialization_form library
This library implements de-/serialization for the application/x-www-form-urlencoded content type.
This library is not meant to be used directly, but rather to be used as a dependency in the generated code.
Classes
- FormParseNode
-
Represents a
ParseNodethat can be used to parse a form url encoded string. - FormParseNodeFactory
-
The
ParseNodeFactoryimplementation for form content types - FormSerializationWriter
- Represents a serialization writer that can be used to write a form url encoded string.
- FormSerializationWriterFactory
- Represents a serialization writer factory that can be used to create a form url encoded serialization writer.